@@ -7,7 +7,7 @@
  * @date   2004-02-01
  * @brief  plugin interface
  *
- * @author Copyright (C) 2004-2017 by Gilles Caulier
+ * @author Copyright (C) 2004-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2012      by Victor Dodon
  *         <a href="mailto:dodonvictor at gmail dot com">dodonvictor at gmail dot com</a>
@@ -36,16 +36,16 @@
 
 // Qt includes
 
-#include <QtCore/QObject>
-#include <QtCore/QList>
-#include <QtCore/QHash>
-#include <QtXml/QDomElement>
-#include <QtXml/QDomNode>
-#include <QtXml/QDomDocument>
+#include <QObject>
+#include <QList>
+#include <QHash>
+#include <QDomElement>
+#include <QDomNode>
+#include <QDomDocument>
 
-// KDE includes
+// KF includes
 
-#include <kxmlguiclient.h>
+#include <KXMLGUIClient>
 
 // Local includes
 
@@ -97,14 +97,14 @@ public:
      * All the actions in the actionCollection are deleted before the plugin is
      * deleted
      */
-    virtual ~Plugin();
+    ~Plugin() override;
 
     /**
      * Returns the plugin actions associated with the widget passed as argument, or with
      * the default widget, if widget is null or not provided. The actions are in
      * the same order as added to the plugin.
      */
-    QList<QAction*> actions(QWidget* const widget = 0) const;
+    QList<QAction*> actions(QWidget* const widget = nullptr) const;
 
     /**
      * Returns the KIPI::Interface
@@ -112,7 +112,7 @@ public:
     Interface* interface() const;
 
     /**
-     * Virtual method that must be overrided by the non abstract descendants and
+     * Virtual method that must be overridden by the non abstract descendants and
      * must be called before any actions are added.
      *
      * @param widget The widget which holds the plugin. It will be set as the default widget.
