@@ -7,7 +7,7 @@
  * @date   2004-02-01
  * @brief  plugin loader
  *
- * @author Copyright (C) 2004-2017 by Gilles Caulier
+ * @author Copyright (C) 2004-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2004-2005 by Renchi Raju
  *         <a href="mailto:renchi dot raju at gmail dot com">renchi dot raju at gmail dot com</a>
@@ -36,12 +36,12 @@
 
 // Qt includes
 
-#include <QtCore/QList>
+#include <QList>
 
-// KDE includes
+// KF includes
 
-#include <kservice.h>
-#include <kxmlguiwindow.h>
+#include <KService>
+#include <KXmlGuiWindow>
 
 // Local includes
 
@@ -59,6 +59,9 @@ class ConfigWidget;
     \par Maintainer: Victor Dodon
     \class PluginLoader
     This is the class that will help host applications to load plugins.
+    
+    This is a singleton and host applications should create the PluginLoader
+    just once, and then use the instance() static method to access it.
 
     The host application must create an instance of the plugin loader, and
     call the method loadPlugins() to get the plugins loaded. To ensure that
@@ -139,6 +142,7 @@ class ConfigWidget;
                 this, SLOT(slotKipiPluginPlug()));
 
         m_loader->loadPlugins();
+        // Do not delete m_loader as long as any of the plugins are in use
     }
 
     void MyKipiApplication::slotKipiPluginPlug()
@@ -226,20 +230,30 @@ public:
 public:
 
     /**
-     * Use this constructor if your application does not use KDE XML GUI technology
+     * Use this constructor if your application does not use KDE XML GUI technology.
+     * 
+     * Note that the PluginLoader is intended to be a singleton, so you
+     * should create only one and then use instance().
      */
     PluginLoader();
 
     /**
      * Standard constructor. You must pass the instance of KDE XML GUI application as argument.
+     * 
+     * Note that the PluginLoader is intended to be a singleton, so you
+     * should create only one and then use instance().
+     * 
      * @param parent the pointer to the KXmlGuiWindow of your application
      */
     PluginLoader(KXmlGuiWindow* const parent);
 
     /**
      * Standard destructor
+     * 
+     * Since PluginLoader is a singleton, you should not call this
+     * in client code.
      */
-    virtual ~PluginLoader();
+    ~PluginLoader() override;
 
     /**
      * Set KIPI interface instance from host application.
@@ -268,7 +282,7 @@ public:
 
     /**
      * Init plugin loader. Call this method to parse relevant plugins installed on your system.
-     * Before to call this method, you must setup KIPI insterface instance.
+     * Before to call this method, you must setup KIPI interface instance.
      * Optionally, setup list of plugins to ignore, the constraint list, and
      * the disabled plugin actions
      */
@@ -305,7 +319,7 @@ Q_SIGNALS:
     void plug(KIPI::PluginLoader::Info*);
     void unplug(KIPI::PluginLoader::Info*);
 
-    // NOTE: plugin can be pluged through Info item.
+    // NOTE: plugin can be plugged through Info item.
     void replug();
 
 private:
