@@ -9,7 +9,7 @@
  *
  * @author Copyright (C) 2009-2010 by Michael G. Hansen
  *         <a href="mailto:mike at mghansen dot de">mike at mghansen dot de</a>
- * @author Copyright (C) 2011-2017 by Gilles Caulier
+ * @author Copyright (C) 2011-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  *
  * This program is free software; you can redistribute it
@@ -47,7 +47,7 @@ namespace KXMLKipiCmd
 KipiImageCollectionSelector::KipiImageCollectionSelector(KipiInterface* const interface, QWidget* const parent)
     : ImageCollectionSelector(parent),
       m_interface(interface),
-      m_listWidget(0)
+      m_listWidget(nullptr)
 {
     QVBoxLayout* const layout = new QVBoxLayout(this);
     layout->addWidget(new QLabel(QString::fromLatin1("Please select albums:")));
