@@ -1,15 +1,15 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of kipi-plugins project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2012-06-20
  * @brief  kipi host test application using KDE XML-GUI technology
  *
  * @author Copyright (C) 2012 by Victor Dodon
  *         <a href="mailto:dodonvictor at gmail dot com">dodonvictor at gmail dot com</a>
- * @author Copyright (C) 2012-2017 by Gilles Caulier
+ * @author Copyright (C) 2012-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  *
  * This program is free software; you can redistribute it
@@ -31,9 +31,9 @@
 
 #include <QUrl>
 
-// KDE includes
+// KF includes
 
-#include <kxmlguiwindow.h>
+#include <KXmlGuiWindow>
 
 namespace KXMLKipiCmd
 {
@@ -47,7 +47,7 @@ public:
     KipiTestMainWindow(const QList<QUrl>& selectedImages,
                        const QList<QUrl>& selectedAlbums,
                        const QList<QUrl>& allAlbums);
-    ~KipiTestMainWindow();
+    ~KipiTestMainWindow() override;
 
     static KipiTestMainWindow* instance();
 
